idlehomescreen/widgetmanager/inc/wmmaincontainerview.h
branchRCL_3
changeset 9 f966699dea19
parent 1 5315654608de
child 34 d05a55b217df
--- a/idlehomescreen/widgetmanager/inc/wmmaincontainerview.h	Tue Feb 02 00:04:13 2010 +0200
+++ b/idlehomescreen/widgetmanager/inc/wmmaincontainerview.h	Fri Feb 19 22:42:37 2010 +0200
@@ -73,6 +73,21 @@
 	 */
 	CWmMainContainer* CreateContainerL();
 	
+   /**
+     * View deactivation function intended for overriding by sub classes.
+     * 
+     * @see CAknView::DoActivateL
+     */
+    void DoDeactivate();
+		
+public: // from MeikMenuObserver
+	
+    /** 
+     * Foreground event handling function.  
+     * @param aForeground Indicates the required focus state of the control.
+     */ 
+    void HandleForegroundEventL( TBool aForeground );
+	    
 private:
     CWmMainContainerView( CWmPlugin& aWmPlugin );    
     void ConstructL();    
@@ -88,13 +103,6 @@
 		TUid aCustomMessageId,
 		const TDesC8& aCustomMessage );
 	
-	/**
-	 * View deactivation function intended for overriding by sub classes.
-	 * 
-	 * @see CAknView::DoActivateL
-	 */
-	void DoDeactivate();
-	
    /**
      * Event handler for status pane size changes.
      * 
@@ -122,8 +130,8 @@
     TBool HandleHelpMenuItemSelectedL();
 	TBool HandleDetailsMenuItemSelectedL();
 	TBool HandleDeactivateFindPaneL();
-	/** setup status pane */
-	void SetupStatusPaneL();
+	/** setup title in status pane */
+	void SetTitleL();
 
 private:
     /**